pub struct ComposePullCommand {
pub executor: CommandExecutor,
pub config: ComposeConfig,
pub services: Vec<String>,
pub ignore_buildable: bool,
pub ignore_pull_failures: bool,
pub include_deps: bool,
pub policy: Option<ComposePullPolicy>,
pub quiet: bool,
}Expand description
Docker Compose pull command builder
Fields
executor: CommandExecutorBase command executor
config: ComposeConfigBase compose configuration
services: Vec<String>Services to pull images for (empty for all)
ignore_buildable: boolIgnore images that can be built
ignore_pull_failures: boolPull what it can and ignore images with pull failures
include_deps: boolAlso pull services declared as dependencies
policy: Option<ComposePullPolicy>Pull policy
quiet: boolPull without printing progress information
Implementations
Sourceimpl ComposePullCommand
impl ComposePullCommand
Sourcepub fn ignore_buildable(self) -> Self
pub fn ignore_buildable(self) -> Self
Ignore images that can be built
Sourcepub fn ignore_pull_failures(self) -> Self
pub fn ignore_pull_failures(self) -> Self
Pull what it can and ignore images with pull failures
Sourcepub fn include_deps(self) -> Self
pub fn include_deps(self) -> Self
Also pull services declared as dependencies
Sourcepub fn policy(self, policy: ComposePullPolicy) -> Self
pub fn policy(self, policy: ComposePullPolicy) -> Self
Set pull policy