pub enum ToxicStream {
Downstream,
Upstream,
}Expand description
Direction a toxic applies to.
Toxiproxy applies toxics to one direction of a proxied connection. The downstream is data flowing from the upstream back to the client; the upstream is data flowing from the client to the upstream.
Variants
Downstream
Data flowing from the upstream service back to the client.
Upstream
Data flowing from the client to the upstream service.